@@ -49,6 +49,9 @@ class server_class():
         for i in idlist:
             nodes[i].model.load_state_dict(self.model.state_dict())
 
+    def client_sampling(self, frac, distribution):
+        pass
+
     def test(self, test_loader):
         correct = 0
         total = 0
@@ -62,7 +65,7 @@ class server_class():
                 total += labels.size(0)
                 correct += (predicted == labels).sum().item()
         print('Accuracy on the %d test cases: %.2f %%' % (total, 100*correct / total))
-        torch.cuda.empty_cache()
+        # torch.cuda.empty_cache()
 
     def model_similarity(model_repr_1, model_repr_2, repr='output'):
         if repr == 'output':
@@ -89,7 +92,6 @@ class server_class():
         # self.clustering['raw'].append(X)
         # self.clustering['center'].append(kmeans.cluster_centers_)
 
-    
     def clustering_plot(self):
         # print(self.clustering)
         # self.clustering =[[1,1,2,2,3,3],[1,1,1,2,2,2],[1, 1, 1, 2, 2, 2],[1, 1, 1, 2, 2, 2]]
